@@ -15,6 +15,7 @@ extern crate log;
 extern crate env_logger as logger;
 
 use std::env;
+use std::iter::once;
 
 #[cfg(windows)]
 pub fn initialize() {
@@ -65,7 +66,7 @@ fn enable_visual_style() {
         GetSystemDirectoryW(sys_dir.as_mut_ptr(), MAX_PATH as u32);
     }
 
-    let mut source = "shell32.dll".encode_utf16().collect::<Vec<u16>>();
+    let mut source = "shell32.dll".encode_utf16().chain(once(0)).collect::<Vec<u16>>();
 
     let mut activation_cookie: ULONG_PTR = 0;
     let mut act_ctx = ACTCTXW {
